main.main

passthrough_decoder.main.main(stop_event=threading.Event(), logger_level=10)

Main processing function for the passthrough decoder.

This function initializes the LSL outlet and stream watcher, waits for the initial delay, and then starts a loop to process incoming data from the stream watcher. It pushes the processed data to the LSL outlet. The configuration is loaded from “./configs/threshold_controller_config.toml”.

Parameters

Name Type Description Default
stop_event threading.Event Event to signal when to stop the processing loop. Defaults to a new event. threading.Event()
logger_level int Logging level for the logger. Defaults to 10 (DEBUG). 10

Returns

Name Type Description
None